pub struct RawBitmapGeneric<S: Storage> { /* private fields */ }Expand description
A simple bitmap backed by generic storage.
Implementations
Sourceimpl<S: Storage> RawBitmapGeneric<S>
impl<S: Storage> RawBitmapGeneric<S>
Sourcepub fn storage_mut(&mut self) -> &mut S
pub fn storage_mut(&mut self) -> &mut S
Access the underlying storage mutably.
Sourcepub fn shrink(&mut self, size: usize) -> Result<(), Status>
pub fn shrink(&mut self, size: usize) -> Result<(), Status>
Shrinks the accessible portion of the bitmap, without re-allocating the underlying storage.
This is useful for programs which require underlying bitmap storage to be aligned to a certain size (initialized via Reset), but want to restrict access to a smaller portion of the bitmap (via Shrink).
Sourcepub fn scan(&self, bitoff: usize, bitmax: usize, is_set: bool) -> Option<usize>
pub fn scan(&self, bitoff: usize, bitmax: usize, is_set: bool) -> Option<usize>
Returns true if all bits in the range [bitoff, bitmax) match is_set.
If they do not match, returns false and the index of the first bit that doesn’t match.
An empty region (i.e. bitoff >= bitmax) will return true.
Sourcepub fn reverse_scan(
&self,
bitoff: usize,
bitmax: usize,
is_set: bool,
) -> Option<usize>
pub fn reverse_scan( &self, bitoff: usize, bitmax: usize, is_set: bool, ) -> Option<usize>
Returns true if all bits in the range [bitoff, bitmax) match is_set, scanning in reverse.
If they do not match, returns false and the index of the last bit that doesn’t match.
An empty region (i.e. bitoff >= bitmax) will return true.
Sourcepub fn reverse_find(
&self,
is_set: bool,
bitoff: usize,
bitmax: usize,
run_len: usize,
) -> Result<usize, Status>
pub fn reverse_find( &self, is_set: bool, bitoff: usize, bitmax: usize, run_len: usize, ) -> Result<usize, Status>
Finds the last run of run_len is_set bits, in [bitoff, bitmax).
Returns the start of the run, or Status::NO_RESOURCES if not found.