RleBitmapBase

Struct RleBitmapBase 

pub struct RleBitmapBase<T> { /* private fields */ }
A run-length encoded bitmap.

Implementations

Source

impl<T> RleBitmapBase<T>

pub fn project<'__pin>( self: Pin<&'__pin mut Self>, ) -> RleBitmapBaseProjection<'__pin, T>

Pin-projects all fields of Self.

These fields are structurally pinned:

  • elems

These fields are not structurally pinned:

  • num_elems
  • num_bits
Source

impl<T> RleBitmapBase<T>

pub fn iter(&self) -> Iterator<'_, ElementPtr<T>>

Returns an iterator over the elements of this bitmap.

Source

impl<T> RleBitmapBase<T>
where T: Copy + Eq + Ord + Default + Add<Output = T> + Sub<Output = T> + From<u8>,

pub fn new() -> impl PinInit<Self, Infallible>

Create a new, empty run-length encoded bitmap.

Since the underlying intrusive list must be pinned in memory, this returns an initializer that must be pinned (e.g. using pin_init::pin_init!).

pub fn num_ranges(&self) -> usize

Returns the current number of ranges (runs of set bits) in the bitmap.

pub fn num_bits(&self) -> T

Returns the current total number of set bits in the bitmap.

pub fn set_no_alloc( &mut self, bitoff: T, bitmax: T, free_list: &mut FreeList<T>, ) -> Result<(), Status>

Sets all bits in the range [bitoff, bitmax).

Only fails if bitmax < bitoff or if an allocation is needed and free_list does not contain one.

free_list is a list of usable allocations. If an allocation is needed, it will be drawn from it. This function is guaranteed to need at most one allocation. If any nodes need to be deleted, they will be appended to free_list.

pub fn clear_no_alloc( &mut self, bitoff: T, bitmax: T, free_list: &mut FreeList<T>, ) -> Result<(), Status>

Clears all bits in the range [bitoff, bitmax).

Only fails if bitmax < bitoff or if an allocation is needed and free_list does not contain one.

free_list is a list of usable allocations. If an allocation is needed, it will be drawn from it. This function is guaranteed to need at most one allocation. If any nodes need to be deleted, they will be appended to free_list.