pub struct RleBitmapBase<T> { /* private fields */ }Expand description
A run-length encoded bitmap.
Implementations
Sourceimpl<T> RleBitmapBase<T>
impl<T> RleBitmapBase<T>
Sourceimpl<T> RleBitmapBase<T>
impl<T> RleBitmapBase<T>
Sourcepub fn iter(&self) -> Iterator<'_, ElementPtr<T>>
pub fn iter(&self) -> Iterator<'_, ElementPtr<T>>
Returns an iterator over the elements of this bitmap.
Sourceimpl<T> RleBitmapBase<T>
impl<T> RleBitmapBase<T>
Sourcepub fn new() -> impl PinInit<Self, Infallible>
pub fn new() -> impl PinInit<Self, Infallible>
Create a new, empty run-length encoded bitmap.
Since the underlying intrusive list must be pinned in memory, this returns
an initializer that must be pinned (e.g. using pin_init::pin_init!).
Sourcepub fn num_ranges(&self) -> usize
pub fn num_ranges(&self) -> usize
Returns the current number of ranges (runs of set bits) in the bitmap.
Sourcepub fn set_no_alloc(
&mut self,
bitoff: T,
bitmax: T,
free_list: &mut FreeList<T>,
) -> Result<(), Status>
pub fn set_no_alloc( &mut self, bitoff: T, bitmax: T, free_list: &mut FreeList<T>, ) -> Result<(), Status>
Sets all bits in the range [bitoff, bitmax).
Only fails if bitmax < bitoff or if an allocation is needed and free_list
does not contain one.
free_list is a list of usable allocations. If an allocation is needed,
it will be drawn from it. This function is guaranteed to need at most
one allocation. If any nodes need to be deleted, they will be appended
to free_list.
Sourcepub fn clear_no_alloc(
&mut self,
bitoff: T,
bitmax: T,
free_list: &mut FreeList<T>,
) -> Result<(), Status>
pub fn clear_no_alloc( &mut self, bitoff: T, bitmax: T, free_list: &mut FreeList<T>, ) -> Result<(), Status>
Clears all bits in the range [bitoff, bitmax).
Only fails if bitmax < bitoff or if an allocation is needed and free_list
does not contain one.
free_list is a list of usable allocations. If an allocation is needed,
it will be drawn from it. This function is guaranteed to need at most
one allocation. If any nodes need to be deleted, they will be appended
to free_list.